<div class="admonition note">
  <p class="admonition-title">Note</p>
  <p>This section is incomplete and will soon be updated.
</p>
</div>

The easiest way to run an AEA is using your development environment.

If you would like to run an AEA from a browser you can use [Google Colab](http://colab.research.google.com). [This gist](https://gist.github.com/DavidMinarsch/2eeb1541508a61e828b497ab161e1834) can be opened in Colab and implements the <a href="../quickstart">quickstart</a>.
